@@ -24,7 +24,7 @@ from zope.location import ILocation
 from zope.location.interfaces import IContained
 from zope.schema import Bool, Choice, Int, List, Object, TextLine
 
-from pyams_security.schema import PermissionField
+from pyams_security.schema import PermissionField, PrincipalsSetField
 from pyams_utils.schema import PersistentListField, PersistentMappingField
 
 from pyams_portal import _  # pylint: disable=ungrouped-imports
@@ -413,6 +413,11 @@ class IPortalTemplate(ILocalTemplateHandler):
                     description=_("Explicit name given to portal template"),
                     required=True)
 
+    css_class = TextLine(title=_("CSS class"),
+                         description=_("This CSS class will be used as main template container "
+                                       "CSS class"),
+                         required=False)
+
 
 class IPortalTemplateContainer(IContainer, IAttributeAnnotatable):
     """Portal template container interface"""
@@ -428,6 +433,16 @@ class IPortalTemplateContainer(IContainer, IAttributeAnnotatable):
         """Get new portlet ID"""
 
 
+class IPortalTemplateContainerRoles(Interface):
+    """Portal templates container roles interface"""
+
+    designers = PrincipalsSetField(title=_("Designers"),
+                                   description=_("List of designers allowed to manage "
+                                                 "presentation templates"),
+                                   role_id=DESIGNER_ROLE,
+                                   required=False)
+
+
 class IPortalTemplateContainerConfiguration(Interface):
     """Portal templates container configuration"""
 
