@@ -18,7 +18,6 @@ This module defines all components required to handle layout of portal templates
 import json
 
 from pyramid.decorator import reify
-from pyramid.httpexceptions import HTTPForbidden
 from pyramid.renderers import render
 from pyramid.view import view_config
 from zope.copy import copy
@@ -28,7 +27,6 @@ from pyams_form.ajax import ajax_form_config
 from pyams_form.button import Buttons, handler
 from pyams_form.field import Fields
 from pyams_form.interfaces.form import IAJAXFormRenderer
-from pyams_i18n.interfaces import II18n
 from pyams_layer.interfaces import IPyAMSLayer
 from pyams_pagelet.pagelet import pagelet_config
 from pyams_portal.interfaces import IPortalContext, IPortalPage, IPortalPortletsConfiguration, \
@@ -48,12 +46,13 @@ from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config
 from pyams_utils.interfaces.intids import IUniqueID
 from pyams_utils.registry import query_utility
 from pyams_utils.traversing import get_parent
+from pyams_viewlet.manager import viewletmanager_config
 from pyams_viewlet.viewlet import viewlet_config
 from pyams_zmi.form import AdminModalAddForm
 from pyams_zmi.interfaces import IAdminLayer, IInnerAdminView
 from pyams_zmi.interfaces.viewlet import IActionsViewletManager, IContentManagementMenu, \
-    IContextAddingsViewletManager, \
-    IMenuHeader, IPropertiesMenu, ISiteManagementMenu
+    IContextAddingsViewletManager, IMenuHeader, IPropertiesMenu, ISiteManagementMenu
+from pyams_zmi.utils import get_object_label
 from pyams_zmi.zmi.viewlet.breadcrumb import AdminLayerBreadcrumbItem
 from pyams_zmi.zmi.viewlet.menu import NavigationMenuItem
 
@@ -70,11 +69,11 @@ def portal_template_menu_header(context, request, view, manager):  # pylint: dis
     return _("Portal template")
 
 
-@viewlet_config(name='layout.menu',
-                context=IPortalTemplate, layer=IAdminLayer,
-                manager=IContentManagementMenu, weight=10,
-                provides=IPropertiesMenu,
-                permission=MANAGE_TEMPLATE_PERMISSION)
+@viewletmanager_config(name='layout.menu',
+                       context=IPortalTemplate, layer=IAdminLayer,
+                       manager=IContentManagementMenu, weight=10,
+                       provides=IPropertiesMenu,
+                       permission=MANAGE_TEMPLATE_PERMISSION)
 class PortalTemplateLayoutMenu(NavigationMenuItem):
     """Portal template layout menu"""
 
@@ -105,6 +104,7 @@ class PortalTemplateLayoutView:
     @property
     def title(self):
         """View title getter"""
+        translate = self.request.localizer.translate
         container = get_parent(self.context, IPortalTemplateContainer)
         if container is None:
             context = get_parent(self.context, IPortalContext)
@@ -113,9 +113,8 @@ class PortalTemplateLayoutView:
                 return _("Local template configuration")
             if page.template.name == LOCAL_TEMPLATE_NAME:
                 return _("Inherited local template configuration")
-            translate = self.request.localizer.translate
-            return translate(_("Shared template configuration ({0})")).format(page.template.name)
-        return _("Template configuration")
+            return translate(_("« {} » shared template configuration")).format(page.template.name)
+        return translate(_("« {} » template configuration")).format(self.context.name)
 
     def get_template(self):
         """Template getter"""
@@ -312,7 +311,7 @@ class PortalContextTemplateShareForm(AdminModalAddForm):
 
     @property
     def title(self):
-        return II18n(self.context).query_attribute('title', request=self.request)
+        return get_object_label(self.context, self.request, self)
 
     legend = _("Share local template")
 
